@@ -25,7 +25,8 @@ class Extraction:
         format = f'.{format}'
         path = re.sub(r"/", r"\\", self.directory)
         Patterns_Abstract = [r"(\\begin{abstract})(?P<Abstract>.+)(\\end{abstract})",
-                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\microtypesetup)",
+                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\tableofcontents)",
+                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\microtypesetup{protrusion=false})",
                              r"(\\chapter{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
                              r"(\\section{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
                              r"(\\RAIstudentthesisAbstract)({.*})(\\RAI)",
